@@ -2,11 +2,10 @@ from typing import Any, Callable
 
 import vapoursynth as vs
 from vskernels import Catrom, Kernel, Scaler
-from vstools import depth, get_depth, get_y, iterate, ColorRange, Matrix
+from vstools import depth, get_depth, get_y, Matrix
+from vsrgtools.sharp import unsharp_masked
 from .types import PathLike
 from abc import ABC, abstractmethod
-from math import floor
-
 core = vs.core
 
 
@@ -179,11 +178,7 @@ class Clamped_Doubler(Doubler):
             elif isinstance(self.sharpen_smooth, Callable):
                 sharpened_smooth = self.sharpen_smooth(smooth)
             elif self.sharpen_smooth == True:
-                try:
-                    import vardefunc as vdf
-                    sharpened_smooth = vdf.sharp.z4usm(smooth, radius, strength)
-                except:
-                    raise "Clamped_Doubler: Couldn't import vardefunc. Please use a different sharpener or none at all."
+                sharpened_smooth = unsharp_masked(smooth, radius, strength)
             
             clamped = core.std.Expr([smooth, shader, sharpened_smooth], 'x y z min max y z max min')
             if self.ratio != 100:
@@ -207,123 +202,26 @@ def vodes_rescale(
     doubler: Kernel | Scaler | Callable[[vs.VideoNode], vs.VideoNode] | Doubler = NNEDI_Doubler(),
     downscaler: Kernel | Scaler | str = Catrom(),
     line_mask: vs.VideoNode | bool = None, credit_mask: vs.VideoNode = None, mask_threshold: float = 0.04,
-    width: float = None, base_height: float = None, do_post_double: Callable[[vs.VideoNode], vs.VideoNode] = None
+    use_baseheight_mask: bool = False, width: float = None, base_height: float = None, base_width: float = None,
+    do_post_double: Callable[[vs.VideoNode], vs.VideoNode] = None
 ) -> list[vs.VideoNode | None]:
     """
-    Rescale function with masking for convenience etc.
+    More or less just a compatibility layer that uses :py:class:`DescaleTarget` from this same package.
+    
+    Check that out to see what the params do.
 
-    :param src:             Input clip
-    :param height:          Height to be descaled to
-    :param width:           Width to be descaled to; will be calculated if you don't pass any
-    :param base_height:     Used for fractional descales
-    :param doubler:         A callable or kernel or Doubler class that will be used to upscale
-    :param descale_kernel:  Kernel used for descaling, supports passing a list of descaled and ref clip instead
-    :param downscaler:      Kernel used to downscale the doubled clip, uses vsscale.ssim_downsample if passed 'ssim'
-    :param line_mask:       Linemask to only rescale lineart | Will generate one if None or skip masking if `False` is passed
-    :param credit_mask:     Credit Masking | Will generate one if None or skip masking if *mask_threshold* is <= 0
-    :param mask_threshold:  Threshold for the diff based credit mask | lower catches more
-    :param do_post_double:  Pass your own function as a lambda if you want to manipulate the clip before the downscale happens
-    :return:                List of rescaled, reference upscale, credit mask and line mask
+    :return:                    List of rescaled, reference upscale, credit mask and line mask
     """
-    wdepth = 16 if get_depth(src) < 16 else get_depth(src)
-    clip = depth(src, wdepth)
-    y = clip if clip.format.color_family == vs.GRAY else get_y(clip)
-
-    if height is None or height < 1:
-        raise ValueError('Rescale: Height may not be None or 0')
-
-    height = float(height)
-
-    if width is None or width < 1:
-        aspect_ratio = src.width / src.height
-        width = height * aspect_ratio
-
-    if not height.is_integer() and base_height is None:
-        raise ValueError("Rescale: height cannot be fractional if you don't pass a base_height")
-
-    if base_height is not None:
-        base_height = float(base_height)
-        if not base_height.is_integer():
-            raise ValueError("Rescale: Your base_height has to be an integer.")
-        if base_height < height:
-            raise ValueError("Rescale: Your base_height has to be bigger than your height.")
-        if (base_height % 2) != 0:
-            raise ValueError("Rescale: Weird things happen when your base_height isn't an even number")
-        
-        src_width = height * clip.width / clip.height
-        cropped_width = clip.width - 2 * floor((clip.width - src_width) / 2)
-        cropped_height = base_height - 2 * floor((base_height - height) / 2)
-        fractional_args = dict(height = cropped_height, width = cropped_width, 
-            src_width = src_width, src_height = height, src_left = (cropped_width - src_width) / 2,
-            src_top = (cropped_height - height) / 2)
-        
-        descaled_y = descale_kernel.descale(y, **fractional_args)
-        fractional_args.pop('width')
-        fractional_args.pop('height')
-        base_height_desc = descale_kernel.descale(y, base_height * (src.width / src.height), base_height)
-        ref_y = descale_kernel.scale(base_height_desc, src.width, src.height)
-    else:
-        descaled_y = descale_kernel.descale(y, width, height) if isinstance(descale_kernel, Kernel) else descale_kernel[0]
-        ref_y = descale_kernel.scale(descaled_y, src.width, src.height) if isinstance(
-            descale_kernel, Kernel) else descale_kernel[1]
-
-    if isinstance(doubler, Doubler):
-        doubled_y = doubler.double(descaled_y)
-    elif isinstance(doubler, Kernel) or isinstance(doubler, Scaler):
-        doubled_y = doubler.scale(descaled_y, descaled_y.width * 2, descaled_y.height * 2)
-    else: 
-        doubled_y = doubler(descaled_y)
-
-    if do_post_double is not None:
-        doubled_y = do_post_double(doubled_y)
-
-    from vsscale import ssim_downsample, SSIM
-    ssim_msg = "Rescale: SSIM does not take src_height and src_width params.\nPlease use something else until setsu fixes it :)"
-
-    if isinstance(downscaler, str) and downscaler.lower() == 'ssim':
-        if base_height is not None:
-            raise ValueError(ssim_msg)
-        rescaled_y = ssim_downsample(depth(doubled_y, 16), src.width, src.height)
-        rescaled_y = depth(rescaled_y, wdepth)
-    else:
-        if base_height is not None:
-            if isinstance(downscaler, SSIM):
-                raise ValueError(ssim_msg)
-            
-            fractional_args.update({key: value * 2 for (key, value) in fractional_args.items()})
-            rescaled_y = downscaler.scale(doubled_y, src.width, src.height, **fractional_args)
-        else:
-            rescaled_y = downscaler.scale(doubled_y, src.width, src.height)
-
-    if credit_mask is None and mask_threshold > 0:
-        credit_mask = core.std.Expr([depth(y, 32), depth(ref_y, 32)], f"x y - abs {mask_threshold} < 0 1 ?")
-        credit_mask = depth(credit_mask, wdepth, range_out=ColorRange.FULL, range_in=ColorRange.FULL)
-        credit_mask = core.rgvs.RemoveGrain(credit_mask, mode=6)
-        credit_mask = iterate(credit_mask, core.std.Maximum, 2)
-        credit_mask = iterate(credit_mask, core.std.Inflate, 2 if do_post_double is None else 4)
-        rescaled_y = core.std.MaskedMerge(rescaled_y, y, credit_mask)
-    elif credit_mask is not None:
-        rescaled_y = core.std.MaskedMerge(rescaled_y, y, credit_mask)
-
-    if line_mask is None or (isinstance(line_mask, bool) and line_mask == True):
-        from vsmask.edge import Kirsch
-        line_mask = Kirsch().edgemask(y, lthr=80 << 8, hthr=150 << 8)
-        if do_post_double is not None:
-            line_mask = core.std.Inflate(line_mask)
-        rescaled_y = core.std.MaskedMerge(y, rescaled_y, line_mask)
-    elif isinstance(line_mask, vs.VideoNode):
-        rescaled_y = core.std.MaskedMerge(y, rescaled_y, line_mask)
-
-    out = rescaled_y if clip.format.color_family == vs.GRAY else \
-        core.std.ShufflePlanes([rescaled_y, clip], [0, 1, 2], vs.YUV)
-    ref_out = ref_y if clip.format.color_family == vs.GRAY else \
-        core.std.ShufflePlanes([ref_y, clip], [0, 1, 2], vs.YUV)
-
+    clip = depth(src, 32)
+    y = get_y(clip)
+    from .descale import DescaleTarget
+    desc = DescaleTarget(height, descale_kernel, doubler, downscaler, base_height, width, base_width, do_post_double, credit_mask, mask_threshold, use_baseheight_mask, line_mask, 0)
+    desc.generate_clips(y)
     blank_mask = core.std.BlankClip(y)
-    return [depth(out, get_depth(src)),
-            depth(ref_out, get_depth(src)),
-            credit_mask if isinstance(credit_mask, vs.VideoNode) else blank_mask,
-            line_mask if isinstance(line_mask, vs.VideoNode) else blank_mask]
+    return [desc.get_upscaled(src),
+            desc.rescale,
+            desc.credit_mask if isinstance(desc.credit_mask, vs.VideoNode) else blank_mask,
+            desc.line_mask if isinstance(desc.line_mask, vs.VideoNode) else blank_mask]
 
 def mod_padding(clip: vs.VideoNode, mod: int = 4, min: int = 4):
     from math import floor
